===========
django todo
===========

django-todo is a pluggable multi-user, multi-group task management and
assignment application for Django. It can serve as anything from a  personal
to-do system to a complete, working ticketing system for organizations.

Documentation
=============

For documentation, see the django-todo wiki pages:

- `Overview and screenshots
  <http://github.com/shacker/django-todo/wiki/Overview-and-screenshots>`_

- `Requirements and installation
  <http://github.com/shacker/django-todo/wiki/Requirements-and-Installation>`_

- `Version history
  <http://github.com/shacker/django-todo/wiki/Version-history>`_
